/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.carbondata.presto;

import com.google.inject.Inject;

import java.util.Objects;

import static java.util.Objects.requireNonNull;

public class CarbondataConnectorId {
  private final String id;

  @Inject public CarbondataConnectorId(String id) {
    this.id = requireNonNull(id, "id is null");
  }

  @Override public String toString() {
    return id;
  }

  @Override public int hashCode() {
    return Objects.hash(id);
  }

  @Override public boolean equals(Object obj) {
    if (this == obj) {
      return true;
    }

    if ((obj == null) || (getClass() != obj.getClass())) {
      return false;
    }

    return Objects.equals(this.id, ((CarbondataConnectorId) obj).id);
  }
}